server_client_20150129_153949

### config1 : test_redlining

Result | Function execution time | Total execution time
--- | --- | ---
Failed | 2.51771092415 sec | 4.84319591522 sec

Error message: server latency too high while sending 10000 integers

Naarad report

### Metrics

#### server1-perf

Submetric | max | mean | min | p50 | p75 | p90 | p95 | p99 | std
--- | --- | --- | --- | --- | --- | --- | --- | --- | ---
latency | 4.54 | 0.41 | 0.25 | 0.39 | 0.43 | 0.47 | 0.5 | 0.83 | 0.15
qps | 622.00 | 333.67 | 13.00 | 366.00 | 494.00 | 570.80 | 596.40 | 616.88 | 249.67

#### client1-perf

Submetric | max | mean | min | p50 | p75 | p90 | p95 | p99 | std
--- | --- | --- | --- | --- | --- | --- | --- | --- | ---
qps | 1.0 | 1.0 | 1.0 | 1.0 | 1.0 | 1.0 | 1.0 | 1.0 | 0.0
latency | 1755.88 | 1755.88 | 1755.88 | 1755.88 | 1755.88 | 1755.88 | 1755.88 | 1755.88 | 0.0

### SLAs

metric | submetric | sla rule | value
--- | --- | --- | ---
server1-perf | latency | p50 lt 0.3 | 0.393
server1-perf | latency | mean lt 0.33 | 0.405110889111
server1-perf | qps | mean lt 7.0 | 333.666666667
server2-perf | latency | p50 lt 0.3 | None
server2-perf | latency | mean lt 0.33 | None
server2-perf | qps | mean lt 7.0 | None
server3-perf | latency | p50 lt 0.3 | None
server3-perf | latency | mean lt 0.33 | None
server3-perf | qps | mean lt 7.0 | None
client1-perf | latency | p50 lt 22.0 | 1755.881
client1-perf | latency | mean lt 35.0 | 1755.881
client1-perf | qps | mean lt 2.0 | 1.0
client2-perf | latency | p50 lt 22.0 | None
client2-perf | latency | mean lt 35.0 | None
client2-perf | qps | mean lt 2.0 | None